==> lnl-3.1.9.tar.gz: lnl-3.1.9/src/menu-prot.h <==
/* menu.c */

#ifdef __cplusplus
extern "C" {
#endif

void	init_var_menu( void );
void	init_menu( void );
void	init_ls_menu_func( void );
char	*exec_menu( menu_t *p, menu_t *dflt, char *str_goto );
bool_t	chk_err_menu_kind( menu_t *ls );
bool_t	set_menu_check_item( menu_t *p );
bool_t	set_menu_radio_item( menu_t *ls, menu_t *p );
ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel );
char	*cb_menu_ask_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_ask_yes( menu_t **pp, menu_t **dflt );
char	*cb_menu_ask_no( menu_t **pp, menu_t **dflt );
char	*exec_menu_sel_num( long *p, long min, long max );
void	sel_menu_clr( draw_menu_t *data );
menu_t	*sel_menu( menu_t *p, menu_t *dflt );
long	set_ls_menu(
	draw_menu_t *data,
	menu_t *p,
	long page_sel_n
);
menu_t	*srch_menu( menu_t *ls, char *sub_path );
menu_t	*srch_next_menu(
	menu_t *ls, menu_t *p, bool_t flg_skip_hidden
);
menu_t	*srch_goto_menu( menu_t *p, char *str_goto );
void	set_chk_on_menu( menu_t *p, char *sub_path );
void	set_chk_off_menu( menu_t *p, char *sub_path );
bool_t	set_flg_menu( menu_t *p, char *sub_path, unsigned long flg );
bool_t	clr_flg_menu( menu_t *p, char *sub_path, unsigned long flg );
bool_t	equ_flg_menu(
	menu_t *p, char *sub_path, unsigned long flg, bool_t flg_set
);
void	wait_key( bool_t flg_can_move_crsr );
void	wait_key_ex( bool_t flg_exec_key, bool_t flg_can_move_crsr );
long	chk_key( bool_t flg_clr_key_buf, bool_t flg_chk_menu );
void	chk_dup_short_key( void );
void	chk_dup_short_key_init( void );
bool_t	chk_dup_short_key_main( menu_t *ls );
bool_t	chk_dup_short_key_sub( unsigned char c, menu_t *ls );
bool_t	chk_short_key( menu_t *ls, long c );
menu_t	*get_ls_menu_func( void );
char	*get_func( long n );
bool_t	get_flg_chk_short_key( void );
bool_t	get_flg_space_select( void );
bool_t	set_flg_space_select( bool_t flg );

#ifdef __cplusplus
}
#endif

==> lnl-3.3.3.tar.gz: lnl-3.3.3/src/menu-prot.h <==
/* menu.c */

#ifdef __cplusplus
extern "C" {
#endif

void	init_var_menu( void );
void	init_menu( void );
void	reset_static_menu( void );
void	init_ls_menu_func( void );
bool_t	chk_executing_menu( void );
char	*exec_menu( menu_t *p, menu_t *dflt, char *str_goto );
char	*exec_menu_sub( menu_t *p, menu_t *dflt, char *str_goto );
void	set_flg_menu_dflt( bool_t flg );
bool_t	get_flg_menu_dflt( void );
bool_t	chk_err_menu_kind( menu_t *ls );
bool_t	set_menu_check_item( menu_t *p );
bool_t	set_menu_radio_item( menu_t *ls, menu_t *p );
ask_t	exec_menu_ask( char *ttl, ask_t dflt, bool_t can_cancel );
char	*cb_menu_ask_init( menu_t **pp, menu_t **dflt );
char	*cb_menu_ask_yes( menu_t **pp, menu_t **dflt );
char	*cb_menu_ask_no( menu_t **pp, menu_t **dflt );
char	*exec_menu_sel_num( long *p, long min, long max );
void	sel_menu_clr( draw_menu_t *data );
menu_t	*sel_menu( menu_t *p, menu_t *dflt );
long	set_ls_menu(
	draw_menu_t *data,
	menu_t *p,
	long page_sel_n
);
menu_t	*srch_menu( menu_t *ls, char *sub_path );
menu_t	*srch_next_menu(
	menu_t *ls, menu_t *p, bool_t flg_skip_hidden
);
menu_t	*srch_goto_menu( menu_t *p, char *str_goto );
void	set_chk_on_menu( menu_t *p, char *sub_path );
void	set_chk_off_menu( menu_t *p, char *sub_path );
bool_t	set_flg_menu( menu_t *p, char *sub_path, unsigned long flg );
bool_t	clr_flg_menu( menu_t *p, char *sub_path, unsigned long flg );
bool_t	equ_flg_menu(
	menu_t *p, char *sub_path, unsigned long flg, bool_t flg_set
);
void	wait_key( bool_t flg_can_move_crsr );
void	wait_key_ex( bool_t flg_exec_key, bool_t flg_can_move_crsr );
long	chk_key( bool_t flg_clr_key_buf, bool_t flg_chk_menu );
void	chk_dup_short_key( void );
void	chk_dup_short_key_init( void );
bool_t	chk_dup_short_key_main( menu_t *ls );
bool_t	chk_dup_short_key_sub( unsigned char c, menu_t *ls );
bool_t	chk_short_key( menu_t *ls, long c );
menu_t	*get_ls_menu_func( void );
char	*get_func( long n );
bool_t	get_flg_chk_menu( void );
bool_t	get_flg_chk_short_key( void );
bool_t	get_flg_space_select( void );
bool_t	set_flg_space_select( bool_t flg );

#ifdef __cplusplus
}
#endif
